@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco++/fmc_all_cls.cc,v 1.65 2014/02/17 23:12:39 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco++/fmc_all_cls.cc,v 1.67 2014/03/25 14:21:26 hmb Exp $ */
 
 /* Purpose: netCDF arithmetic processor class methods: families of functions/methods */
 
@@ -705,12 +705,13 @@ var_sct * utl_cls::is_fnd(bool &is_mtd, std::vector<RefAST> &args_vtr, fmc_cls &
       int iret=0;
       switch(lcl_typ){
         case VVAR: 
-           if(prs_arg->ncap_var_init_chk(va_nm)) iret=1;
-           break;
+          if(prs_arg->ncap_var_init_chk(va_nm)) 
+            iret=1;
+          break;
         case VATT:
 	  if( prs_arg->var_vtr.find(va_nm) !=NULL)
 	    iret=1;
-          else if( (var1=ncap_att_init(va_nm,prs_arg))!=NULL) ;      
+          else if( (var1=ncap_att_init(va_nm,prs_arg))!=NULL) 
             iret=1;
           break;   
 
@@ -2698,390 +2699,6 @@ double bil_cls::clc_lin_ipl(double x1,double x2, double x, double Q0,double Q1){
   }
 
 
-//misc Functions /******************************************/
-// These fuctions are used to create and apply masks to 2D grid variables
-//    mask_out=imask_make(var_in,lat,lon)
-//
-//    var_in is a 2D var. mask_out is a 0/1 mask of grid points.
-//    value is set to 1 if point in var_in is  missing_value but has a neigbour with a non-missing value;
-//
-//    var_out=imask_fill(var_in.mask_out,lat,lon)
-//  
-//    Points  in var_in are filled if they are missing AND are specified in mask_out.
-//    The fill value is an average from the nearest neigbours. nb if a neighbour has just been filled 
-//    in then this value is NOT used in the calculation of the average      
-//    Typically mask_out and var_in should be the same shape. 
-//    Howver its possible to specify multiple mask in mask_out - in this case each mask is iterativly applied to var_in
-//    so the shape would be like mask_out(mask_size,lat,lon) 
-// 
-//
-//
-  misc_cls::misc_cls(bool flg_dbg){
-    //Populate only on first constructor call
-    if(fmc_vtr.empty()){
-      fmc_vtr.push_back( fmc_cls("imask",this,(int)PMISC1));
-      fmc_vtr.push_back( fmc_cls("imask_make",this,(int)PMISC2));
-      fmc_vtr.push_back( fmc_cls("imask_fill",this,(int)PMISC3));
-    }
-  }
-
-
-
-
-  var_sct *misc_cls::fnd(RefAST expr, RefAST fargs,fmc_cls &fmc_obj, ncoTree &walker){
-  const std::string fnc_nm("misc_cls::fnd");
-    int idx;
-    int fdx=fmc_obj.fdx();   //index
-    int nbr_args;
-    int in_nbr_args;
-    prs_cls* prs_arg=walker.prs_arg;
-    var_sct *var_arr[4];
-    var_sct *var_out;
-    RefAST tr;
-    nc_type in_typ;  
-    std::string susg;
-    std::string serr;
-    std::string sfnm =fmc_obj.fnm(); //method name
-    std::vector<RefAST> vtr_args; 
-    NcapVector<dmn_sct*> dmn_vtr;
-
-
-    if(expr)
-      vtr_args.push_back(expr);
-
-    if(tr=fargs->getFirstChild()) {
-       do  
-         vtr_args.push_back(tr);
-       while(tr=tr->getNextSibling());    
-    } 
-
-      
-    nbr_args=vtr_args.size();  
-
-    switch(fdx){
-
-      case PMISC1:
-       in_nbr_args=nbr_args;  
-       susg="usage: var_out="+sfnm+"(Data_2D, X_in, Y_in)"; 
-       break;
-
-      case PMISC2: 
-        in_nbr_args=nbr_args;  
-        susg="usage: var_out="+sfnm+"(data_2D, mask,X_in?, Y_in?)"; 
-        break;
-
-
-      case PMISC3:
-       in_nbr_args=nbr_args;  
-       susg="usage: var_out="+sfnm+"(data_2D,mask, X_in, Y_in)"; 
-       break;
-
-
-    } // end switch
-
-
-    if(in_nbr_args <3 ){   
-      serr="function requires at least two arguments. You have only supplied "+nbr2sng(in_nbr_args)+ " arguments\n"; 
-      err_prn(sfnm,serr+susg);
-    }
-
-    
-   
-    // process input args 
-    for(idx=0 ; idx<in_nbr_args; idx++)
-      var_arr[idx]=walker.out(vtr_args[idx]);
-
-   
-    // initial scan
-    if(prs_arg->ntl_scn){
-        for(idx=1 ; idx<in_nbr_args ; idx++)
-	    nco_var_free(var_arr[idx]);
-
-        return var_arr[0];
-    }
-
-    // save inital type
-    in_typ=var_arr[0]->type;     
-    // convert all args to type DOUBLE 
-    for(idx=0;idx<in_nbr_args;idx++)
-       var_arr[idx]=nco_var_cnf_typ(NC_DOUBLE,var_arr[idx]);               
-
-   
-
-    if(fdx==PMISC1){
-      // recall input arguments in order
-      // 0 - input data
-      // 1 - input X   co-ordinate var
-      // 2 - input Y   co-ordinate var
-      long cnt=0l; 
-      long ldx; 
-      long idx;
-      long jdx;
-      long v_sz;
-      long iidx;
-      long jjdx;
-      long lldx; 
-      long x_sz;
-      long y_sz;
-      double *dpi;
-      double *dpo;
-      double mss_dbl=9.999e20;; 
-
-      var_out=nco_var_dpl(var_arr[0]);
-      (void)cast_void_nctype(NC_DOUBLE,&var_out->val);   
-
-      for(idx=0;idx<in_nbr_args;idx++) 
-         (void)cast_void_nctype(NC_DOUBLE,&var_arr[idx]->val);
-
-      // grab missing value;  
-      if( var_arr[0]->has_mss_val ){
-         cast_void_nctype(NC_DOUBLE,&var_arr[0]->mss_val);
-         mss_dbl=*var_arr[0]->mss_val.dp;      
-         cast_nctype_void(NC_DOUBLE,&var_arr[0]->mss_val);       
-       }   
-
-      dpi=var_arr[0]->val.dp; 
-      dpo=var_out->val.dp;          
-      v_sz=var_arr[0]->sz;     
-      x_sz=var_arr[1]->sz;   
-      y_sz=var_arr[2]->sz;   
-
-      
-      
-      // set all values to zero      
-     memset((void*)dpo,0, sizeof(double) *v_sz);     
-
-     for(idx=2;idx<x_sz-2; idx++)       
-       for(jdx=2;jdx<y_sz-2;jdx++ ){
-         ldx=idx*y_sz+jdx; 
-         // set output to default missing vale; 
-         dpo[ldx]=mss_dbl; 
-         // mask either 1 or mss_dbl
-	 if( dpi[ldx] !=1.0 ){
-	   for(iidx=idx-2; iidx<idx+3;iidx++){ 
-	     for(jjdx=jdx-2; jjdx<jdx+3;jjdx++){ 
-	       lldx=iidx*y_sz+jjdx;
-	        if(dpi[lldx]==1.0){
-		  dpo[ldx]=1.0;  
-                  cnt++; 
-                  goto outer; 
-	        }             
-	     }
-           }
-	 } 
-       outer: ;
-       }
-       
-     printf("misc_cls number of spots processed=%ld\n" ,cnt);
-                       
-    } // end fdx
-
-    if(fdx==PMISC2){
-      // recall input arguments in order
-      // 0 - input var -2D INPUT GRID 
-      // 1 - input X   co-ordinate var
-      // 2 - input Y   co-ordinate var
-      long ldx;  
-      long v_sz;
-      long x_sz;
-      long y_sz;
-      long mcnt=0l;   // num missing values count 
-      long vmcnt=0l; // num missing processed;   
-      double mss_dbl=9.999e20; 
-      double *dpi;   // input pointer
-      double *dpo;   //output pointer 
-      double *dpm;   // mask pointer;  
-      // save in type; 
-      ostringstream os; 
-      
-      // var_out is the output mask - same shape as input var 
-      var_out=nco_var_dpl(var_arr[0]);         
-      (void)cast_void_nctype(NC_DOUBLE,&var_out->val); 
-
-      // cast all vars
-      for(idx=0;idx<in_nbr_args;idx++)
-        (void)cast_void_nctype(NC_DOUBLE,&var_arr[idx]->val);
-        
-      v_sz=var_arr[0]->sz;
-      x_sz=var_arr[1]->sz;
-      y_sz=var_arr[2]->sz;
-   
-      
-      dpo=var_out->val.dp;
-      dpi=var_arr[0]->val.dp;     
-      dpm=var_arr[1]->val.dp;      
- 
-      // grab missing value;  
-     if( var_arr[0]->has_mss_val ){
-         cast_void_nctype(NC_DOUBLE,&var_arr[0]->mss_val);
-         mss_dbl=*var_arr[0]->mss_val.dp;      
-         cast_nctype_void(NC_DOUBLE,&var_arr[0]->mss_val);       
-       }   
-      
-      for(ldx=0; ldx<v_sz ; ldx++){
-        // set otuput to default -0.0 
-        dpo[ldx]=0.0;
-
-        if(dpi[ldx]==mss_dbl ){  
-          int cnt=0;  
-          int jdx;
-          long iX=ldx/y_sz;
-          long iY= ldx -iX*y_sz;
-          double sum=0.0;
-          double Q[4]={mss_dbl,mss_dbl,mss_dbl,mss_dbl};
-          mcnt++; 
-            
-  
-          if(iY >0 )    Q[0]=dpi[ldx-1];
-          if(iY+1<y_sz) Q[1]=dpi[ldx+1]; 
-          if(iX>0 )     Q[2]=dpi[ldx-y_sz];
-          if(iX+1 < x_sz) Q[3]=dpi[ldx+y_sz];   
-           
-          for(jdx=0 ; jdx<4 ;jdx++)
-	    if(Q[jdx] !=mss_dbl) {
-	      sum+=Q[jdx];              
-              cnt++; 
-	    }
-       
-	  if(cnt){ 
-	    dpo[ldx]=1.0;   
-            vmcnt++;
-	  }
-           
-	} // end if
-               
-      } // end for
-
-      if(nco_dbg_lvl_get() >= 2){ 
-          os<< sfnm<<": num missing="<<mcnt<<+" num valid="<<vmcnt;
-          dbg_prn(fnc_nm,os.str());
-      } 
-
-    } // end fdx  
-
-
-    if(fdx==PMISC3){
-      // recall input arguments in order
-      // 0 - input var -2D INPUT GRID 
-      // 1 - input mask 2D GRID (VARMASK these are the places we want to fill a value)
-      //     nb this mask may contain multiple masks. So size of mask is a multiple of the
-      //     the input size grid i.e mask size = n * v_sz, When its a multiple we apply each mask
-      //     i an iteration    
-      // 2 - input X   co-ordinate var
-      // 3 - input Y   co-ordinate var
-      long ldx;  
-      long mdx;
-      long v_sz;
-      long m_sz;
-      long x_sz;
-      long y_sz;
-      size_t m_offset=0ll; 
-      double mss_dbl=9.999e20; 
-      double *dpi;   // input pointer
-      double *dpo;   //output pointer 
-      double *dpm;   // mask pointer;  
-   
-      // save in type; 
-      
-
-
-      var_out=nco_var_dpl(var_arr[0]);         
-      (void)cast_void_nctype(NC_DOUBLE,&var_out->val);
-
-      // cast all arguments
-      for(idx=0;idx<in_nbr_args;idx++)
-        (void)cast_void_nctype(NC_DOUBLE,&var_arr[idx]->val);
-
-      v_sz=var_arr[0]->sz;
-      m_sz=var_arr[1]->sz; 
-      x_sz=var_arr[2]->sz;
-      y_sz=var_arr[3]->sz;
-      
-    
-      assert(v_sz==x_sz*y_sz); 
-      // check mask size  
-      assert(m_sz % v_sz ==0l);    
-     
-      dpo=var_out->val.dp;
-      dpi=var_arr[0]->val.dp;     
- 
- 
-      // grab missing value;  
-      if( var_arr[0]->has_mss_val ){
-	cast_void_nctype(NC_DOUBLE,&var_arr[0]->mss_val);
-	mss_dbl=*var_arr[0]->mss_val.dp;      
-	cast_nctype_void(NC_DOUBLE,&var_arr[0]->mss_val);       
-      }   
-
-      for(mdx=0;mdx < m_sz/v_sz ; mdx++){  
-        long mcnt=0l;
-        long vmcnt=0l;        
-	ostringstream os; 
-        dpm=var_arr[1]->val.dp+mdx*v_sz;
-
-        // copy new values into input pointer !!
-        // dont want dpi and dpo the same
-        if(mdx >0)
-          memcpy(dpi,dpo, v_sz* sizeof(double));    
-
-	for(ldx=0; ldx<v_sz ; ldx++){
-	  //check mask  
-	  // if(dpm[ldx]==1.0 && dpi[ldx]==mss_dbl){  
-	  // if( dpi[ldx]==mss_dbl) dpo[ldx]=0.0; 
-	  // if(dpm[ldx]==1.0 && dpi[ldx]==mss_dbl){     
-	  if(dpi[ldx]==mss_dbl && dpm[ldx]==1.0){  
-	    int cnt=0;  
-	    int jdx;  
-	    long iX=ldx/y_sz;
-	    long iY= ldx -iX*y_sz;
-	    double sum=0.0;
-	    double Q[4]={mss_dbl,mss_dbl,mss_dbl,mss_dbl};
-	    mcnt++;
-       
-	    if(iY >0 )    Q[0]=dpi[ldx-1];
-	    if(iY+1<x_sz) Q[1]=dpi[ldx+1]; 
-	    if(iX>0 )     Q[2]=dpi[ldx-y_sz];
-	    if(iX+1 < x_sz) Q[3]=dpi[ldx+y_sz];   
-           
-	    for(jdx=0 ; jdx<4 ;jdx++){
-	      if(Q[jdx] !=mss_dbl) {
-		sum+=Q[jdx];              
-		cnt++; 
-	      }
-	    }
-	    if(cnt){ 
-	      dpo[ldx]=sum/cnt;
-	      vmcnt++;  
-	    } 
-
-	  } // end if
-
-	} // end for ldx 
-
-        if(nco_dbg_lvl_get() >= 2){ 
-	      os<< sfnm<<" mask num="<<mdx<<" : num missing="<<mcnt<<+" num processed="<<vmcnt;
-              dbg_prn(fnc_nm,os.str());
-	} 
-         
-      } // end for mdx
-    } 
-
-    // cast everything back to void,and free up
-    for(idx=0;idx<in_nbr_args;idx++){
-      (void)cast_nctype_void(NC_DOUBLE,&var_arr[idx]->val);
-      nco_var_free(var_arr[idx]);
-    } 
-
-    (void)cast_nctype_void(NC_DOUBLE,&var_out->val);    
-    // change back to input type  
-    var_out=nco_var_cnf_typ(in_typ,var_out);
-    
-
-    return var_out;
-
-
-  }// end  
-
 /*****************************************************************************************************************/
 /* ncap2 functions and methods */
 
