@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.489 2014/02/18 06:38:36 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.506 2014/03/26 18:55:58 pvicente Exp $ */
 
 /* Purpose: netCDF Operator (NCO) definitions */
 
@@ -802,7 +802,7 @@ extern "C" {
     char *dmn_nm;         /* [sng] Dimension name */
     long dmn_sz_org;      /* [nbr] Original size of dimension */
     long dmn_cnt;         /* [nbr] Hyperslabbed size of dimension */  
-    nco_bool BASIC_DMN;   /* [flg] Limit is same as dimension in input file */
+    nco_bool NON_HYP_DMN;   /* [flg] Limit is same as dimension in input file */
     nco_bool WRP;         /* [flg] Limit is wrapped (true if wrapping, lmt_dmn_nbr==2) */ 
     nco_bool MSA_USR_RDR; /* [flg] Multi-Slab Algorithm returns hyperslabs in user-specified order */
     int lmt_dmn_nbr;      /* [nbr] Number of lmt arguments */
@@ -947,6 +947,7 @@ extern "C" {
   /* Dimension structure */
   typedef struct dmn_sct_tag{ /* dmn_sct */
     char *nm; /* [sng] Dimension name */
+    char *nm_fll; /* [sng] Dimension full name */
     char fmt[5]; /* [sng] Hint for printf()-style formatting */
     int cid; /* [id] Variable ID of associated coordinate, if any */
     int id; /* [id] Dimension ID */
@@ -971,16 +972,18 @@ extern "C" {
     int var_nbr;            /* [nbr] Number of variable for this group (size of above array) */ 
   } nsm_grp_sct; 
 
+
   /* Ensemble (ncge) */
   typedef struct{
     char *grp_nm_fll_prn;   /* [sng] Parent group full name (key for ensemble) (e.g., /cesm) */
     nsm_grp_sct *mbr;       /* [sng] List of ensemble group member structs (size is mbr_nbr) */
-    char **var_mbr_fll;     /* [sng] List of variable ensemble members (e.g., /cesm/cesm_01/tas) */
-    char **grp_mbr_fll;     /* [sng] List of group ensemble members (e.g., /cesm/cesm_01) */
-    int mbr_nbr;            /* [nbr] Number of members (groups) of ensemble (i.e., number in this ensemble in this file) */ 
-    int mbr_var_nbr;        /* [nbr] Number of variable members of ensemble */           
-    int mbr_srt;            /* [nbr] Member offsets (multi files, keep track of new added members) */ 
-    int mbr_end;            /* [nbr] Member offsets (multi files, keep track of new added members) */ 
+    int mbr_nbr;            /* [nbr] Number of members (groups) of ensemble (i.e., number in this ensemble in this file) */
+    char **tpl_mbr_nm;      /* [sng] List of variable that act as templates (first, store relative name) (e.g., /cesm/cesm_01/tas) */
+    int tpl_nbr;            /* [nbr] Number of variables that are templates in group */  
+    char **skp_nm_fll;      /* [sng] Skip list (fixed variables to define at ensemble parent group, store full name) (e.g., /cesm/cesm_01/time)  */
+    int skp_nbr;            /* [nbr] Number of skip list variables */ 
+    int mbr_srt;            /* [nbr] Member offsets, start (multi files, keep track of new added members) */ 
+    int mbr_end;            /* [nbr] Member offsets, end (multi files, keep track of new added members) */ 
   } nsm_sct; 
 
   
@@ -990,16 +993,15 @@ extern "C" {
   } nm_sct;
 
   /* Name list structure */
-  typedef struct{ /* nm_tbl_sct */
+  typedef struct{ 
     nm_sct *lst;  /* [sct] List of nm_sct (char * currently) */
     int nbr;      /* [nbr] Number of items in "lst" array */
-  } nm_tbl_sct;
+  } nm_lst_sct;
 
   /* GTT (Group Traversal Table) structure contains two lists
      1) lst: All objects (variables and groups) in file tree (HDF5 model)
      2) lst_dmn: All unique dimensions (in groups) in file tree (netCDF addition to HDF5) */
   typedef struct{
-    /* Members used by all operators */
     trv_sct *lst;           /* [sct] Array of trv_sct */
     unsigned int nbr;       /* [nbr] Number of trv_sct elements */   
     dmn_trv_sct *lst_dmn;   /* [sct] Array of dmn_trv_sct */
@@ -1010,7 +1012,6 @@ extern "C" {
     int nsm_nbr;            /* [nbr] (ncge) Number of ensembles (i.e., number in first file) */ 
     nsm_sct *nsm;           /* [lst] (ncge) List of ensembles (size is nsm_nbr) */ 
     char *nsm_sfx;          /* [sng] (ncge) Ensemble suffix (e.g., /cesm + _avg). Store here instead of passing as function parameters (ncge only) */
-    nm_tbl_sct *nsm_skp;    /* [lst] (ncge) Skip list (fixed variables to define at ensemble parent group) */ 
   } trv_tbl_sct;
  
   /* GPE duplicate name check structure */
@@ -1097,7 +1098,7 @@ extern "C" {
     char *nm_fll; /* [sng] Full dimension name */
     nco_bool is_rec_dmn; /* [flg] Is a record dimension/coordinate? */
     size_t sz; /* [nbr] Size of dimension/coordinate */
-    nco_bool BASIC_DMN; /* [flg] Limit is same as dimension in input file */
+    nco_bool NON_HYP_DMN; /* [flg] Limit is same as dimension in input file */
     size_t dmn_cnt; /* [nbr] Hyperslabbed size of dimension */ 
     int id; /* [id] Dimension ID */ 
   } dmn_cmn_sct; 
