@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.h,v 1.113 2014/02/15 20:21:08 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.h,v 1.116 2014/03/05 01:07:14 pvicente Exp $ */
 
 /* Purpose: netCDF4 traversal storage */
 
@@ -80,6 +80,12 @@ trv_tbl_mrk_xtr                        /* [fnc] Mark extraction flag in table fo
  const nco_bool flg_xtr,               /* I [flg] Flag (True or False) */
  trv_tbl_sct * const trv_tbl);         /* I/O [sct] Traversal table */
 
+void
+trv_tbl_mrk_grp_xtr                   /* [fnc] Mark extraction flag in table for "grp_nm_fll" */
+(const char * const grp_nm_fll,       /* I [sng] Group name to find */
+ const nco_bool flg_xtr,              /* I [flg] Flag (True or False) */
+ trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
+
 void
 trv_tbl_mrk_prc_fix                    /* [fnc] Mark fixed/processed flag in table for "var_nm_fll" */
 (const char * const var_nm_fll,        /* I [sng] Variable name to find */
@@ -182,5 +188,15 @@ nco_strrstr                            /* [fnc] Searches a substring starting fr
 (const char *str,                      /* [fnc] String */
  const char *str_fnd);                 /* [fnc] String to find */
 
+trv_sct *                              /* O [sct] Table object */
+trv_tbl_var_nm                         /* [fnc] Return variable object (relative name) */
+(const char * const var_nm,            /* I [sng] Variable name to find */
+ const trv_tbl_sct * const trv_tbl);   /* I [sct] Traversal table */
+
+trv_sct *                              /* O [sct] Table object */
+trv_tbl_nsm_nm                         /* [fnc] Return variable object  */
+(const char * const var_nm,            /* I [sng] Variable name (relative) to find */
+ const char * const grp_nm_fll_prn,    /* I [sng] Ensemble parent group */
+ const trv_tbl_sct * const trv_tbl);   /* I [sct] Traversal table */
 
 #endif /* NCO_GRP_TRV_H */
