@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_utl.h,v 1.461 2014/02/19 21:36:44 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_utl.h,v 1.494 2014/03/29 20:48:00 pvicente Exp $ */
 
 /* Purpose: Group utilities */
 
@@ -210,6 +210,12 @@ void
 nco_xtr_dmn_mrk                      /* [fnc] Mark extracted dimensions */
 (trv_tbl_sct * const trv_tbl);       /* I/O [sct] GTT (Group Traversal Table) */
 
+nco_bool                                                         
+nco_pth_mth                            /* [fnc] Name component in full path matches user string  */
+(char * const nm_fll,                  /* I [sng] Full name (path) */
+ char * const nm,                      /* I [sng] Name (relative) */
+ char * const usr_sng);                /* [sng] User-supplied object name */
+
 void
 nco_xtr_grp_mrk                      /* [fnc] Mark extracted groups */
 (trv_tbl_sct * const trv_tbl);       /* I/O [sct] GTT (Group Traversal Table) */
@@ -304,7 +310,7 @@ void
 nco_get_rec_dmn_nm                     /* [fnc] Return array of record names  */
 (const trv_sct * const var_trv,        /* I [sct] Variable object */
  const trv_tbl_sct * const trv_tbl,    /* I [sct] GTT (Group Traversal Table) */
- nm_tbl_sct ** rec_dmn_nm);            /* I/O [sct] Array of record names */
+ nm_lst_sct ** rec_dmn_nm);            /* I/O [sct] Array of record names */
  
 void
 nco_prs_aux_crd                       /* [fnc] Parse auxiliary coordinates */
@@ -355,7 +361,7 @@ nco_prc_cmn                            /* [fnc] Process objects (ncbo only) */
  trv_sct * trv_2,                      /* I [sct] Table object */
  trv_tbl_sct * const trv_tbl_1,        /* I/O [sct] GTT (Group Traversal Table) */
  trv_tbl_sct * const trv_tbl_2,        /* I/O [sct] GTT (Group Traversal Table) */
- nco_bool flg_grp_1,                   /* I [flg] Use table 1 as template for group creation on True, otherwise use table 2 */
+ const nco_bool flg_grp_1,             /* I [flg] Use table 1 as template for group creation on True, otherwise use table 2 */
  const nco_bool flg_dfn);              /* I [flg] Action type (True for define variables, False when write variables ) */
 
 void                          
@@ -381,43 +387,6 @@ nco_pck_cpy_att                        /* [fnc] Inquire about copying packing at
  const int nco_pck_plc,                /* I [enm] Packing policy */
  const var_sct * const var_prc);       /* I [sct] Variable */
 
-nco_bool                               /* O [flg] True for match found */
-nco_rel_mch                            /* [fnc] Relative match of object in table 1 to table 2  */
-(const int nc_id_1,                    /* I [id] netCDF input-file ID from file 1 */
- const int nc_id_2,                    /* I [id] netCDF input-file ID from file 2 */
- const int nc_out_id,                  /* I [id] netCDF output-file ID */
- const cnk_sct * const cnk,            /* I [sct] Chunking structure */
- const int dfl_lvl,                    /* I [enm] Deflate level [0..9] */
- const gpe_sct * const gpe,            /* I [sct] GPE structure */
- gpe_nm_sct *gpe_nm,                   /* I/O [sct] GPE name duplicate check array */
- int nbr_gpe_nm,                       /* I/O [nbr] Number of GPE entries */  
- const nco_bool CNV_CCM_CCSM_CF,       /* I [flg] File adheres to NCAR CCM/CCSM/CF conventions */
- const int nco_op_typ,                 /* I [enm] Operation type (command line -y) */
- trv_sct * var_trv,                    /* I [sct] Table variable object (can be from table 1 or 2) */
- nco_bool flg_tbl_1,                   /* I [flg] Table variable object is from table1 for True, otherwise is from table 2 */
- nco_bool flg_grp_1,                   /* I [flg] Use table 1 as template for group creation on True, otherwise use table 2 */
- trv_tbl_sct * const trv_tbl_1,        /* I/O [sct] GTT (Group Traversal Table) */
- trv_tbl_sct * const trv_tbl_2,        /* I/O [sct] GTT (Group Traversal Table) */
- const nco_bool flg_dfn);              /* I [flg] Action type (True for define variables, False when write variables ) */
-
-void                          
-nco_prc_cmn_nm                         /* [fnc] Process common objects from a common mames list  */
-(const int nc_id_1,                    /* I [id] netCDF input-file ID */
- const int nc_id_2,                    /* I [id] netCDF input-file ID */
- const int nc_out_id,                  /* I [id] netCDF output-file ID */
- const cnk_sct * const cnk,            /* I [sct] Chunking structure */
- const int dfl_lvl,                    /* I [enm] Deflate level [0..9] */
- const gpe_sct * const gpe,            /* I [sct] GPE structure */
- gpe_nm_sct *gpe_nm,                   /* I/O [sct] GPE name duplicate check array */
- int nbr_gpe_nm,                       /* I/O [nbr] Number of GPE entries */  
- const nco_bool CNV_CCM_CCSM_CF,       /* I [flg] File adheres to NCAR CCM/CCSM/CF conventions */
- const int nco_op_typ,                 /* I [enm] Operation type (command line -y) */
- trv_tbl_sct * const trv_tbl_1,        /* I/O [sct] GTT (Group Traversal Table) */
- trv_tbl_sct * const trv_tbl_2,        /* I/O [sct] GTT (Group Traversal Table) */
- const nco_cmn_t * const cmn_lst,      /* I [sct] List of common names */
- const int nbr_cmn_nm,                 /* I [nbr] Number of common names entries */
- const nco_bool flg_dfn);              /* I [flg] Action type (True for define variables, False when write variables ) */
-
 void
 nco_var_prc_fix_trv                    /* [fnc] Store processed and fixed variables info into GTT */
 (const int nbr_var_prc,                /* I [nbr] Number of processed variables */
@@ -577,6 +546,7 @@ nco_bld_trv_tbl                       /* [fnc] Construct GTT, Group Traversal Ta
  const nco_bool flg_unn,              /* I [flg] Select union of specified groups and variables */
  const nco_bool EXCLUDE_INPUT_LIST,   /* I [flg] Exclude rather than extract groups and variables specified with -v */ 
  const nco_bool EXTRACT_ASSOCIATED_COORDINATES,  /* I [flg] Extract all coordinates associated with extracted variables? */ 
+ const int nco_pck_plc,               /* I [enm] Packing policy */
  nco_dmn_dne_t **flg_dne,             /* I/O [lst] Flag to check if input dimension -d "does not exist" */
  trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
 
@@ -660,21 +630,6 @@ nco_grp_var_lst                        /* [fnc] Export list of variable names fo
  char ***nm_lst,                       /* I/O [sng] List of names */
  int *nm_lst_nbr);                     /* I/O [nbr] Number of items in list */
 
-void
-nco_bld_nsm                           /* [fnc] Build ensembles */
-(const int nc_id,                     /* I [id] netCDF file ID */
- trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
-
-void                          
-nco_nm_skp                             /* [fnc] Extract list of variable names to skip for template definition  */
-(const int nc_id,                      /* I [ID] netCDF file ID */
- const char * const grp_nm_fll,        /* I [sng] Group full name where all names reside */
- const nco_cmn_t *cmn_lst,             /* I [sct] List of names (relative)  */
- const int nbr_cmn_nm,                 /* I [nbr] Number of names (size of above array) */
- nco_cmn_t **skp_lst,                  /* I/O [sct] List of skip names (full) */
- int * nbr_skp_nm,                     /* I/O [nbr] Number of skip names (size of above array) */
- const trv_tbl_sct * const trv_tbl);   /* I [sct] GTT (Group Traversal Table) */
-
 char *                                /* O [sng] Name of variable   */
 nco_var_has_cf                        /* [fnc] Variable has CF-compliant information ("coordinates" or "bounds") */
 (const int nc_id,                     /* I [ID] netCDF file ID */
@@ -774,6 +729,20 @@ nco_dmn_lmt                            /* [fnc] Convert a lmt_sct array to dmn_s
  const int nbr_lmt,                    /* I [nbr] Size of lmt_sct array  */
  dmn_sct ***dmn);                      /* O [sct] dmn_sct array  */
 
+void
+nco_prn_nsm                           /* [fnc] Print ensembles  */                                
+(const trv_tbl_sct * const trv_tbl);  /* I [sct] Traversal table */
+
+
+
+void
+nco_bld_nsm                           /* [fnc] Build ensembles */
+(const int nc_id,                     /* I [id] netCDF file ID */
+ const nco_bool flg_fix_xtr,          /* I [flg] Mark fized variables as extracted  */
+ const nco_bool CNV_CCM_CCSM_CF,      /* I [flg] File adheres to NCAR CCM/CCSM/CF conventions */
+ const int nco_pck_plc,               /* I [enm] Packing policy */
+ trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
+
 void
 nco_nsm_dfn_wrt                       /* [fnc] Define OR write ensemble fixed variables */
 (const int nc_id,                     /* I [ID] netCDF input file ID */
@@ -781,18 +750,194 @@ nco_nsm_dfn_wrt                       /* [fnc] Define OR write ensemble fixed va
  const cnk_sct * const cnk,           /* I [sct] Chunking structure */
  const int dfl_lvl,                   /* I [enm] Deflate level [0..9] */
  const gpe_sct * const gpe,           /* I [sct] GPE structure */
- const nco_bool flg_def,              /* [fnc] Define OR write */
+ const nco_bool flg_def,              /* I [flg] Define OR write */
  trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
 
-
 void
 nco_nsm_ncr                           /* [fnc] Increase ensembles (more than 1 file cases) */
 (const int nc_id,                     /* I [id] netCDF file ID */
  trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
 
+
+nco_bool                               /* O [flg] True for match found */
+nco_prc_rel_mch                        /* [fnc] Relative match of object in table 1 to table 2  */
+(const int nc_id_1,                    /* I [id] netCDF input-file ID from file 1 */
+ const int nc_id_2,                    /* I [id] netCDF input-file ID from file 2 */
+ const int nc_out_id,                  /* I [id] netCDF output-file ID */
+ const cnk_sct * const cnk,            /* I [sct] Chunking structure */
+ const int dfl_lvl,                    /* I [enm] Deflate level [0..9] */
+ const gpe_sct * const gpe,            /* I [sct] GPE structure */
+ gpe_nm_sct *gpe_nm,                   /* I/O [sct] GPE name duplicate check array */
+ int nbr_gpe_nm,                       /* I/O [nbr] Number of GPE entries */  
+ const nco_bool CNV_CCM_CCSM_CF,       /* I [flg] File adheres to NCAR CCM/CCSM/CF conventions */
+ const int nco_op_typ,                 /* I [enm] Operation type (command line -y) */
+ trv_sct * var_trv,                    /* I [sct] Table variable object (can be from table 1 or 2) */
+ const nco_bool flg_tbl_1,             /* I [flg] Table variable object is from table1 for True, otherwise is from table 2 */
+ const nco_bool flg_grp_1,             /* I [flg] Use table 1 as template for group creation on True, otherwise use table 2 */
+ trv_tbl_sct * const trv_tbl_1,        /* I/O [sct] GTT (Group Traversal Table) */
+ trv_tbl_sct * const trv_tbl_2,        /* I/O [sct] GTT (Group Traversal Table) */
+ const nco_bool flg_dfn);              /* I [flg] Action type (True for define variables, False when write variables ) */
+
+
+void                          
+nco_cmn_var                            /* [fnc] Does the list of common names contain absolute variables match? */
+(const trv_tbl_sct * const trv_tbl_1,  /* I [sct] GTT (Group Traversal Table) */
+ const trv_tbl_sct * const trv_tbl_2,  /* I [sct] GTT (Group Traversal Table) */
+ const nco_cmn_t * const cmn_lst,      /* I [sct] List of common names */
+ const int nbr_cmn_nm,                 /* I [nbr] Number of common names entries */
+ nco_bool *flg_cmn_abs,                /* I/O [flg] Does the list of common names contain absolute variables match? */
+ nco_bool *flg_cmn_rel);               /* I/O [flg] Does the list of common names contain relative variables match? */
+
+
+void                                               
+nco_prc_cmn_var_nm_fll                 /* [fnc] Process (define, write) absolute variables in both files (same path) (ncbo) */
+(const int nc_id_1,                    /* I [id] netCDF input-file ID */
+ const int nc_id_2,                    /* I [id] netCDF input-file ID */
+ const int nc_out_id,                  /* I [id] netCDF output-file ID */
+ const cnk_sct * const cnk,            /* I [sct] Chunking structure */
+ const int dfl_lvl,                    /* I [enm] Deflate level [0..9] */
+ const gpe_sct * const gpe,            /* I [sct] GPE structure */
+ gpe_nm_sct *gpe_nm,                   /* I/O [sct] GPE name duplicate check array */
+ int nbr_gpe_nm,                       /* I/O [nbr] Number of GPE entries */  
+ const nco_bool CNV_CCM_CCSM_CF,       /* I [flg] File adheres to NCAR CCM/CCSM/CF conventions */
+ const int nco_op_typ,                 /* I [enm] Operation type (command line -y) */
+ trv_tbl_sct * const trv_tbl_1,        /* I/O [sct] GTT (Group Traversal Table) */
+ trv_tbl_sct * const trv_tbl_2,        /* I/O [sct] GTT (Group Traversal Table) */
+ const nco_cmn_t * const cmn_lst,      /* I [sct] List of common names */
+ const int nbr_cmn_nm,                 /* I [nbr] Number of common names entries */
+ const nco_bool flg_dfn);              /* I [flg] Action type (True for define variables, False for write variables ) */
+
+void                          
+nco_grp_brd2                           /* [fnc] Group broadcasting (ncbo only) */
+(const int nc_id_1,                    /* I [id] netCDF input-file ID */
+ const int nc_id_2,                    /* I [id] netCDF input-file ID */
+ const int nc_out_id,                  /* I [id] netCDF output-file ID */
+ const cnk_sct * const cnk,            /* I [sct] Chunking structure */
+ const int dfl_lvl,                    /* I [enm] Deflate level [0..9] */
+ const gpe_sct * const gpe,            /* I [sct] GPE structure */
+ gpe_nm_sct *gpe_nm,                   /* I/O [sct] GPE name duplicate check array */
+ int nbr_gpe_nm,                       /* I/O [nbr] Number of GPE entries */  
+ const nco_bool CNV_CCM_CCSM_CF,       /* I [flg] File adheres to NCAR CCM/CCSM/CF conventions */
+ const int nco_op_typ,                 /* I [enm] Operation type (command line -y) */
+ trv_tbl_sct * const trv_tbl_1,        /* I/O [sct] GTT (Group Traversal Table) */
+ trv_tbl_sct * const trv_tbl_2,        /* I/O [sct] GTT (Group Traversal Table) */
+ const nco_bool flg_dfn);              /* I [flg] Action type (True for define variables, False for write variables ) */
+
+void                          
+nco_grp_brd                            /* [fnc] Group broadcasting (ncbo only) */
+(const int nc_id_1,                    /* I [id] netCDF input-file ID */
+ const int nc_id_2,                    /* I [id] netCDF input-file ID */
+ const int nc_out_id,                  /* I [id] netCDF output-file ID */
+ const cnk_sct * const cnk,            /* I [sct] Chunking structure */
+ const int dfl_lvl,                    /* I [enm] Deflate level [0..9] */
+ const gpe_sct * const gpe,            /* I [sct] GPE structure */
+ gpe_nm_sct *gpe_nm,                   /* I/O [sct] GPE name duplicate check array */
+ int nbr_gpe_nm,                       /* I/O [nbr] Number of GPE entries */  
+ const nco_bool CNV_CCM_CCSM_CF,       /* I [flg] File adheres to NCAR CCM/CCSM/CF conventions */
+ const int nco_op_typ,                 /* I [enm] Operation type (command line -y) */
+ trv_tbl_sct * const trv_tbl_1,        /* I/O [sct] GTT (Group Traversal Table) */
+ trv_tbl_sct * const trv_tbl_2,        /* I/O [sct] GTT (Group Traversal Table) */
+ const nco_bool flg_dfn);              /* I [flg] Action type (True for define variables, False for write variables ) */
+
+
+void                          
+nco_cmn_nsm_var                        /* [fnc] Common variable exist in ensembles (ncbo only) */
+(nco_bool *flg_var_cmn,                /* I/O [flg] Common variable exists */
+ nco_bool *flg_var_cmn_rth,            /* I/O [flg] Common variable exists at root */
+ nm_lst_sct **var_nm,                  /* I/O [sct] Array of common variable names */ 
+ nm_lst_sct **var_nm_rth,              /* I/O [sct] Array of common variable names at root */ 
+ const trv_tbl_sct * const trv_tbl_1,  /* I [sct] GTT (Group Traversal Table) */
+ const trv_tbl_sct * const trv_tbl_2); /* I [sct] GTT (Group Traversal Table) */
+
+void                                               
+nco_prc_cmn_nsm                        /* [fnc] Process (define, write) variables belonging to ensembles in both files (ncbo) */
+(const int nc_id_1,                    /* I [id] netCDF input-file ID */
+ const int nc_id_2,                    /* I [id] netCDF input-file ID */
+ const int nc_out_id,                  /* I [id] netCDF output-file ID */
+ const cnk_sct * const cnk,            /* I [sct] Chunking structure */
+ const int dfl_lvl,                    /* I [enm] Deflate level [0..9] */
+ const gpe_sct * const gpe,            /* I [sct] GPE structure */
+ gpe_nm_sct *gpe_nm,                   /* I/O [sct] GPE name duplicate check array */
+ int nbr_gpe_nm,                       /* I/O [nbr] Number of GPE entries */  
+ const nco_bool CNV_CCM_CCSM_CF,       /* I [flg] File adheres to NCAR CCM/CCSM/CF conventions */
+ const int nco_op_typ,                 /* I [enm] Operation type (command line -y) */
+ trv_tbl_sct * const trv_tbl_1,        /* I/O [sct] GTT (Group Traversal Table) */
+ trv_tbl_sct * const trv_tbl_2,        /* I/O [sct] GTT (Group Traversal Table) */
+ const nco_bool flg_grp_1,             /* I [flg] Use table 1 as template for group creation on True, otherwise use table 2 */
+ const nco_bool flg_dfn);              /* I [flg] Action type (True for define variables, False for write variables ) */
+
+
+void                                               
+nco_prc_nsm                            /* [fnc] Process (define, write) variables belonging to ensembles only in 1 file (ncbo) */
+(const int nc_id_1,                    /* I [id] netCDF input-file ID */
+ const int nc_id_2,                    /* I [id] netCDF input-file ID */
+ const int nc_out_id,                  /* I [id] netCDF output-file ID */
+ const cnk_sct * const cnk,            /* I [sct] Chunking structure */
+ const int dfl_lvl,                    /* I [enm] Deflate level [0..9] */
+ const gpe_sct * const gpe,            /* I [sct] GPE structure */
+ gpe_nm_sct *gpe_nm,                   /* I/O [sct] GPE name duplicate check array */
+ int nbr_gpe_nm,                       /* I/O [nbr] Number of GPE entries */  
+ const nco_bool CNV_CCM_CCSM_CF,       /* I [flg] File adheres to NCAR CCM/CCSM/CF conventions */
+ const int nco_op_typ,                 /* I [enm] Operation type (command line -y) */
+ trv_tbl_sct * const trv_tbl_1,        /* I/O [sct] GTT (Group Traversal Table) */
+ trv_tbl_sct * const trv_tbl_2,        /* I/O [sct] GTT (Group Traversal Table) */
+ const nm_lst_sct * const var_lst,     /* I [sct] Array of common variable names from file not having ensembles */ 
+ const nco_bool flg_grp_1,             /* I [flg] Use table 1 as template for group creation on True, otherwise use table 2 */
+ const nco_bool flg_dfn);               /* I [flg] Action type (True for define variables, False for write variables ) */
+
+void                          
+nco_fix_dfn_wrt                        /* [fnc] Define/write fixed variables (ncbo) */
+(const int nc_id,                      /* I [id] netCDF input-file ID */
+ const int nc_out_id,                  /* I [id] netCDF output-file ID */
+ const cnk_sct * const cnk,            /* I [sct] Chunking structure */
+ const int dfl_lvl,                    /* I [enm] Deflate level [0..9] */
+ const gpe_sct * const gpe,            /* I [sct] GPE structure */
+ gpe_nm_sct *gpe_nm,                   /* I/O [sct] GPE name duplicate check array */
+ int nbr_gpe_nm,                       /* I/O [nbr] Number of GPE entries */  
+ trv_sct * trv,                        /* I [sct] Table object */
+ trv_tbl_sct * const trv_tbl,          /* I/O [sct] GTT (Group Traversal Table) */
+ const nco_bool flg_dfn);              /* I [flg] Action type (True for define variables, False when write variables ) */
+
+
+nco_bool                               /* O [flg] True for match found */
+nco_rel_mch                            /* [fnc] Relative match of object in table 1 to table 2  */
+(trv_sct * var_trv,                    /* I [sct] Table variable object (can be from table 1 or 2) */
+ const nco_bool flg_tbl_1,             /* I [flg] Table variable object is from table1 for True, otherwise is from table 2 */
+ const trv_tbl_sct * const trv_tbl_1,  /* I [sct] GTT (Group Traversal Table) */
+ const trv_tbl_sct * const trv_tbl_2); /* I [sct] GTT (Group Traversal Table) */
+
+
+void                          
+nco_prc_rel_cmn_nm                     /* [fnc] Process common relative objects from a common mames list (ncbo only) */
+(const int nc_id_1,                    /* I [id] netCDF input-file ID */
+ const int nc_id_2,                    /* I [id] netCDF input-file ID */
+ const int nc_out_id,                  /* I [id] netCDF output-file ID */
+ const cnk_sct * const cnk,            /* I [sct] Chunking structure */
+ const int dfl_lvl,                    /* I [enm] Deflate level [0..9] */
+ const gpe_sct * const gpe,            /* I [sct] GPE structure */
+ gpe_nm_sct *gpe_nm,                   /* I/O [sct] GPE name duplicate check array */
+ int nbr_gpe_nm,                       /* I/O [nbr] Number of GPE entries */  
+ const nco_bool CNV_CCM_CCSM_CF,       /* I [flg] File adheres to NCAR CCM/CCSM/CF conventions */
+ const int nco_op_typ,                 /* I [enm] Operation type (command line -y) */
+ trv_tbl_sct * const trv_tbl_1,        /* I/O [sct] GTT (Group Traversal Table) */
+ trv_tbl_sct * const trv_tbl_2,        /* I/O [sct] GTT (Group Traversal Table) */
+ const nco_cmn_t * const cmn_lst,      /* I [sct] List of common names */
+ const int nbr_cmn_nm,                 /* I [nbr] Number of common names entries */
+ const nco_bool flg_dfn);              /* I [flg] Action type (True for define variables, False when write variables ) */
+
+
 void
-nco_prn_nsm                           /* [fnc] Print ensembles  */                                
-(const trv_tbl_sct * const trv_tbl);  /* I [sct] Traversal table */
+nco_chk_nsm                            /* [fnc] Check if ensembles are valid  */                                
+(const int in_id,                      /* I [id] netCDF input-file ID of current file, starting with first  */
+ const int fl_idx,                     /* I [nbr] Index of file loop  */
+ const trv_tbl_sct * const trv_tbl);   /* I [sct] GTT (Group Traversal Table) of *first* file */
+
+void                          
+nco_nsm_att                            /* [fnc] Inquire if ensemble parent group has "ensemble" attribute (ncbo only) */
+(const int nc_id,                      /* I [id] netCDF file ID  */
+ const trv_tbl_sct * const trv_tbl,    /* I [sct] GTT (Group Traversal Table) */
+ nco_bool *flg_nsm_att);               /* I/O [flg] "ensemble" attribute exists */
+
 
 #ifdef __cplusplus
 } /* end extern "C" */
