@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_msa.c,v 1.238 2014/02/14 05:22:17 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_msa.c,v 1.243 2014/03/25 00:09:20 pvicente Exp $ */
 
 /* Purpose: Multi-slabbing algorithm */
 
@@ -77,7 +77,7 @@ nco_msa_rcr_clc /* [fnc] Multi-slab algorithm (recursive routine, returns a sing
     cp_fst=0L;
 
     /* Deal first with wrapped dimensions
-    True if wrapped dims or slabs DO NOT overlap or user-specified order */
+       True if wrapped dims or slabs DO NOT overlap or user-specified order */
     if(lmt_lst[dpt_crr]->WRP || lmt_lst[dpt_crr]->MSA_USR_RDR){
 
       for(slb_idx=0;slb_idx<nbr_slb;slb_idx++){
@@ -143,10 +143,12 @@ read_lbl:
     { /* begin potential OpenMP critical */
       /* Check for stride */
       if(var_sz > 0){ /* Allow for zero-size record variables TODO nco711 */
-        if(srd_prd == 1L)
-          (void)nco_get_vara(vara->nc_id,vara->id,dmn_srt,dmn_cnt,vp,vara->type);
-        else
-          (void)nco_get_varm(vara->nc_id,vara->id,dmn_srt,dmn_cnt,dmn_srd,(long *)NULL,vp,vara->type);
+	/* 20140304: User reported extreme slowdown accessing 3-D data with strides across DAP connection
+	   Info from R. Signell and J. Whitaker suggests using nco_get_vars() instead of nco_get_varm() may be crucial
+	   Tests bear this out: get_varm() is tortuously slow across DAP 
+	   Always use get_vars() for strides unless using full get_varm() mapping vector */
+	/*          (void)nco_get_varm(vara->nc_id,vara->id,dmn_srt,dmn_cnt,dmn_srd,(long *)NULL,vp,vara->type); */
+        if(srd_prd == 1L) (void)nco_get_vara(vara->nc_id,vara->id,dmn_srt,dmn_cnt,vp,vara->type); else (void)nco_get_vars(vara->nc_id,vara->id,dmn_srt,dmn_cnt,dmn_srd,vp,vara->type);
       } /* end if var_sz */
     } /* end potential OpenMP critical */
 
@@ -305,7 +307,7 @@ nco_msa_ram_2_dsk /* Convert hyperslab indices (in RAM) to hyperlsab indices rel
     size=lmt_msa[idx]->lmt_dmn_nbr;
     if(dmn_sbs_ram[idx] == dmn_sbs_prv[idx]) continue;
 
-    if(lmt_msa[idx]->BASIC_DMN){
+    if(lmt_msa[idx]->NON_HYP_DMN){
       dmn_sbs_dsk[idx]=dmn_sbs_ram[idx];
       continue;
     }
@@ -569,7 +571,7 @@ nco_msa_lmt_all_ntl
     lmt_all_crr->lmt_dmn_nbr=1;
     lmt_all_crr->dmn_sz_org=dmn_sz;
     lmt_all_crr->WRP=False;
-    lmt_all_crr->BASIC_DMN=True;
+    lmt_all_crr->NON_HYP_DMN=True;
     lmt_all_crr->MSA_USR_RDR=False;    
 
     lmt_all_crr->lmt_dmn[0]=(lmt_sct *)nco_malloc(sizeof(lmt_sct)); 
@@ -605,7 +607,7 @@ nco_msa_lmt_all_ntl
     for(jdx=0;jdx<nbr_dmn_fl;jdx++){
       if(!strcmp(lmt[idx]->nm,lmt_all_lst[jdx]->dmn_nm)){   
         lmt_all_crr=lmt_all_lst[jdx];
-        lmt_all_crr->BASIC_DMN=False;
+        lmt_all_crr->NON_HYP_DMN=False;
         if(lmt_all_crr->lmt_dmn[0]->lmt_typ == -1) { 
           /* Free defualt limit set above structure first */
           lmt_all_crr->lmt_dmn[0]=(lmt_sct*)nco_lmt_free(lmt_all_crr->lmt_dmn[0]);
@@ -739,7 +741,7 @@ nco_msa_var_val_cpy /* [fnc] Copy variables data from input to output file */
         if(srd_prd == 1L)
           nco_put_vara(out_id,var[idx]->xrf->id,var[idx]->xrf->srt,var[idx]->xrf->cnt,var[idx]->val.vp,var[idx]->type);
         else
-          nco_put_varm(out_id,var[idx]->xrf->id,var[idx]->xrf->srt,var[idx]->xrf->cnt,var[idx]->xrf->srd,(long *)NULL,var[idx]->val.vp,var[idx]->type);
+          nco_put_vars(out_id,var[idx]->xrf->id,var[idx]->xrf->srt,var[idx]->xrf->cnt,var[idx]->xrf->srd,var[idx]->val.vp,var[idx]->type);
 
       } /* end if var_sz */
     } /* end if variable is an array */
@@ -1344,7 +1346,7 @@ nco_cpy_msa_lmt                     /* [fnc] Copy MSA struct from table to local
       /* And copy the structure made while building limits  */
       (*lmt_msa)[dmn_idx_var]->dmn_nm=strdup(var_trv->var_dmn[dmn_idx_var].crd->nm);
 
-      (*lmt_msa)[dmn_idx_var]->BASIC_DMN=var_trv->var_dmn[dmn_idx_var].crd->lmt_msa.BASIC_DMN;
+      (*lmt_msa)[dmn_idx_var]->NON_HYP_DMN=var_trv->var_dmn[dmn_idx_var].crd->lmt_msa.NON_HYP_DMN;
       (*lmt_msa)[dmn_idx_var]->dmn_cnt=var_trv->var_dmn[dmn_idx_var].crd->lmt_msa.dmn_cnt;
       (*lmt_msa)[dmn_idx_var]->dmn_sz_org=var_trv->var_dmn[dmn_idx_var].crd->sz;
       (*lmt_msa)[dmn_idx_var]->lmt_dmn_nbr=var_trv->var_dmn[dmn_idx_var].crd->lmt_msa.lmt_dmn_nbr;
@@ -1399,7 +1401,7 @@ nco_cpy_msa_lmt                     /* [fnc] Copy MSA struct from table to local
       /* And copy the structure made while building limits  */
       (*lmt_msa)[dmn_idx_var]->dmn_nm=strdup(var_trv->var_dmn[dmn_idx_var].ncd->nm);
 
-      (*lmt_msa)[dmn_idx_var]->BASIC_DMN=var_trv->var_dmn[dmn_idx_var].ncd->lmt_msa.BASIC_DMN;
+      (*lmt_msa)[dmn_idx_var]->NON_HYP_DMN=var_trv->var_dmn[dmn_idx_var].ncd->lmt_msa.NON_HYP_DMN;
       (*lmt_msa)[dmn_idx_var]->dmn_cnt=var_trv->var_dmn[dmn_idx_var].ncd->lmt_msa.dmn_cnt;
       (*lmt_msa)[dmn_idx_var]->dmn_sz_org=var_trv->var_dmn[dmn_idx_var].ncd->sz;
       (*lmt_msa)[dmn_idx_var]->lmt_dmn_nbr=var_trv->var_dmn[dmn_idx_var].ncd->lmt_msa.lmt_dmn_nbr;
@@ -1457,6 +1459,8 @@ nco_msa_var_get_trv                 /* [fnc] Get variable data from disk taking
  var_sct *var_in,                   /* I/O [sct] Variable */
  const trv_tbl_sct * const trv_tbl) /* I [sct] GTT (Group Traversal Table) */
 {
+  const char fnc_nm[]="nco_msa_var_get_trv()"; /* [sng] Function name  */
+
   int nbr_dim;
   int grp_id;
 
@@ -1495,6 +1499,23 @@ nco_msa_var_get_trv                 /* [fnc] Get variable data from disk taking
   /* Copy from table to local MSA */
   (void)nco_cpy_msa_lmt(var_trv,&lmt_msa);
 
+
+  if(nco_dbg_lvl_get() == nco_dbg_old){
+    (void)fprintf(stdout,"%s: DEBUG %s reading <%s>\n",nco_prg_nm_get(),fnc_nm,var_trv->nm_fll);
+    /* Loop dimensions */
+    for(int idx_dmn=0;idx_dmn<var_trv->nbr_dmn;idx_dmn++){
+      (void)fprintf(stdout,"%s: DEBUG %s <%s> elements %ld",nco_prg_nm_get(),fnc_nm,
+        lmt_msa[idx_dmn]->dmn_nm,lmt_msa[idx_dmn]->dmn_cnt);
+      for(int idx_lmt=0;idx_lmt<lmt_msa[idx_dmn]->lmt_dmn_nbr;idx_lmt++){
+        (void)fprintf(stdout," : %ld (%ld->%ld)",lmt_msa[idx_dmn]->lmt_dmn[idx_lmt]->cnt,
+          lmt_msa[idx_dmn]->lmt_dmn[idx_lmt]->srt,
+          lmt_msa[idx_dmn]->lmt_dmn[idx_lmt]->end);
+      }
+      (void)fprintf(stdout,"\n");
+    } /* Loop dimensions */
+  }
+
+
   /* Call super-dooper recursive routine */
   typ_tmp=var_in->type;
   var_in->type=var_in->typ_dsk; 
