@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_lst.c,v 1.166 2014/01/03 06:04:07 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_lst.c,v 1.168 2014/03/27 18:25:16 pvicente Exp $ */
 
 /* Purpose: Variable list utilities */
 
@@ -870,8 +870,7 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
   int idx_dmn;
   int idx_xcl;
   int var_op_typ[NC_MAX_VARS];
-
-  nco_bool is_sz_rnk_prv_rth_opr; /* [flg] Size- and rank-preserving operator */
+  
   nco_bool var_typ_fnk=False; /* [flg] Variable type is too funky for arithmetic */ /* CEWI */
 
   nc_type var_typ=NC_NAT; /* NC_NAT present in netcdf.h version netCDF 3.5+ */
@@ -890,9 +889,7 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
   var_fix=(var_sct **)nco_malloc(NC_MAX_VARS*sizeof(var_sct *));
   var_fix_out=(var_sct **)nco_malloc(NC_MAX_VARS*sizeof(var_sct *));
   var_prc=(var_sct **)nco_malloc(NC_MAX_VARS*sizeof(var_sct *));
-  var_prc_out=(var_sct **)nco_malloc(NC_MAX_VARS*sizeof(var_sct *));
-
-  is_sz_rnk_prv_rth_opr=nco_is_sz_rnk_prv_rth_opr(nco_prg_id,nco_pck_plc);
+  var_prc_out=(var_sct **)nco_malloc(NC_MAX_VARS*sizeof(var_sct *));  
 
   /* Find operation type for each variable: for now this is either fix or prc */
   for(idx=0;idx<nbr_var;idx++){
@@ -1010,39 +1007,13 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
       if(var[idx]->sz == 0L) var_op_typ[idx]=fix_typ;
 
     if(CNV_CCM_CCSM_CF){
-      if(!strcmp(var_nm,"ntrm") || !strcmp(var_nm,"ntrn") || !strcmp(var_nm,"ntrk") || !strcmp(var_nm,"ndbase") || !strcmp(var_nm,"nsbase") || !strcmp(var_nm,"nbdate") || !strcmp(var_nm,"nbsec") || !strcmp(var_nm,"mdt") || !strcmp(var_nm,"mhisf")) var_op_typ[idx]=fix_typ;
-      /* NB: all !strcmp()'s except "msk_" which uses strstr() */
-      if(is_sz_rnk_prv_rth_opr && (!strcmp(var_nm,"hyam") || !strcmp(var_nm,"hybm") || !strcmp(var_nm,"hyai") || !strcmp(var_nm,"hybi") || !strcmp(var_nm,"gw") || !strcmp(var_nm,"lon_bnds") || !strcmp(var_nm,"lat_bnds") || !strcmp(var_nm,"area") || !strcmp(var_nm,"ORO") || !strcmp(var_nm,"date") || !strcmp(var_nm,"datesec") || (strstr(var_nm,"msk_") == var_nm))) var_op_typ[idx]=fix_typ;
-      /* Known "multi-dimensional coordinates" in CCSM-like model output:
-	 lat, lon, lev are normally 1-D coordinates
-	 Known exceptions:
-	 lat and lon are "2-D coordinates" in NARCCAP output
-	 NARCCAP specifies lat and lon in "coordinates" attribute of 2-D fields
-	 latixy and longxy are "2-D coordinates" in CLM output
-	 CLM does not specify latixy and longxy in "coordinates" attribute of any fields
-	 NARCCAP output gives all "coordinate-like" fields an "axis" attribute
-	 This includes the record coordinate (i.e., "time") which both ncra and ncwa _should_ process
-	 CLM does not give an "axis" attribute to any fields
-	 One method of chasing down all "coordinate-like" fields is to look
-	 for the field name in the "coordinates" attribute of any variable.
-	 However, this will miss (false-negative) the case when no variables 
-	 use an N-D coordinate-like variable as a coordinate. 
-	 And this may hit (false-positive) the record coordinate (often "time")
-	 which should be averaged by ncra, though perhaps not by nces.
-	 "coordinate-like" variables that should be "fixed", and not
-	 differenced, interpolated, or ensemble-averaged, include those 
-	 satisfying these conditions:
-	 0. Traditional coordinate (1-D variable same name as its dimension)
-	 1. Present in a "coordinates" attribute (except "time" for ncra)
-	 2. Present in a "bounds" attribute (except "time_bnds" for ncra)
-	 3. Contain an "axis" attribute (except "time") fxm not done yet
-	 4. Found in empirical list of variables
-	 NB: In the above algorithm discussion, "time" is my shorthand 
-	 for "the record variable, if any" */
-      
-      /* Conditions #1 and #2 are already implemented above in the case() statement */
-      /* Check condition #4 above: */
-      if(is_sz_rnk_prv_rth_opr && (!strcmp(var_nm,"lat") || !strcmp(var_nm,"lon") || !strcmp(var_nm,"lev") || !strcmp(var_nm,"longxy") || !strcmp(var_nm,"latixy") )) var_op_typ[idx]=fix_typ;
+
+      nco_bool var_is_fix;  /* [fnc] Variable should be treated as a fixed variable */
+
+      var_is_fix=nco_var_is_fix(var_nm,nco_prg_id,nco_pck_plc);  
+
+      if (var_is_fix) var_op_typ[idx]=fix_typ;
+
     } /* end if CNV_CCM_CCSM_CF */
 
     /* Warn about any expected weird behavior */
@@ -1147,15 +1118,12 @@ nco_var_lst_dvd_trv                          /* [fnc] Divide input lists into ou
   int idx_xcl;
   prc_typ_enm var_op_typ;
 
-  nco_bool is_sz_rnk_prv_rth_opr; /* [flg] Size- and rank-preserving operator */
   nco_bool var_typ_fnk=False;     /* [flg] Variable type is too funky for arithmetic */ 
 
   nc_type var_typ=NC_NAT;         /* NC_NAT present in netcdf.h version netCDF 3.5+ */
 
   nco_prg_id=nco_prg_id_get(); 
 
-  is_sz_rnk_prv_rth_opr=nco_is_sz_rnk_prv_rth_opr(nco_prg_id,nco_pck_plc);
-
   /* Initialize operation type to processed. Change to fixed where warranted later. */
   var_op_typ=prc_typ;
   var_nm=var->nm;
@@ -1256,39 +1224,13 @@ nco_var_lst_dvd_trv                          /* [fnc] Divide input lists into ou
       var_op_typ=fix_typ;
 
   if(CNV_CCM_CCSM_CF){
-    if(!strcmp(var_nm,"ntrm") || !strcmp(var_nm,"ntrn") || !strcmp(var_nm,"ntrk") || !strcmp(var_nm,"ndbase") || !strcmp(var_nm,"nsbase") || !strcmp(var_nm,"nbdate") || !strcmp(var_nm,"nbsec") || !strcmp(var_nm,"mdt") || !strcmp(var_nm,"mhisf")) var_op_typ=fix_typ;
-    /* NB: all !strcmp()'s except "msk_" which uses strstr() */
-    if(is_sz_rnk_prv_rth_opr && (!strcmp(var_nm,"hyam") || !strcmp(var_nm,"hybm") || !strcmp(var_nm,"hyai") || !strcmp(var_nm,"hybi") || !strcmp(var_nm,"gw") || !strcmp(var_nm,"lon_bnds") || !strcmp(var_nm,"lat_bnds") || !strcmp(var_nm,"area") || !strcmp(var_nm,"ORO") || !strcmp(var_nm,"date") || !strcmp(var_nm,"datesec") || (strstr(var_nm,"msk_") == var_nm))) var_op_typ=fix_typ;
-    /* Known "multi-dimensional coordinates" in CCSM-like model output:
-       lat, lon, lev are normally 1-D coordinates
-       Known exceptions:
-       lat and lon are "2-D coordinates" in NARCCAP output
-       NARCCAP specifies lat and lon in "coordinates" attribute of 2-D fields
-       latixy and longxy are "2-D coordinates" in CLM output
-       CLM does not specify latixy and longxy in "coordinates" attribute of any fields
-       NARCCAP output gives all "coordinate-like" fields an "axis" attribute
-       This includes the record coordinate (i.e., "time") which both ncra and ncwa _should_ process
-       CLM does not give an "axis" attribute to any fields
-       One method of chasing down all "coordinate-like" fields is to look
-       for the field name in the "coordinates" attribute of any variable.
-       However, this will miss (false-negative) the case when no variables 
-       use an N-D coordinate-like variable as a coordinate. 
-       And this may hit (false-positive) the record coordinate (often "time")
-       which should be averaged by ncra, though perhaps not by nces.
-       "coordinate-like" variables that should be "fixed", and not
-       differenced, interpolated, or ensemble-averaged, include those 
-       satisfying these conditions:
-       0. Traditional coordinate (1-D variable same name as its dimension)
-       1. Present in a "coordinates" attribute (except "time" for ncra)
-       2. Present in a "bounds" attribute (except "time_bnds" for ncra)
-       3. Contain an "axis" attribute (except "time") fxm not done yet
-       4. Found in empirical list of variables
-       NB: In the above algorithm discussion, "time" is my shorthand 
-       for "the record variable, if any" */
-    
-    /* Conditions #1 and #2 are already implemented above in the case() statement */
-    /* Check condition #4 above: */
-    if(is_sz_rnk_prv_rth_opr && (!strcmp(var_nm,"lat") || !strcmp(var_nm,"lon") || !strcmp(var_nm,"lev") || !strcmp(var_nm,"longxy") || !strcmp(var_nm,"latixy") )) var_op_typ=fix_typ;
+
+    nco_bool var_is_fix;  /* [fnc] Variable should be treated as a fixed variable */
+
+    var_is_fix=nco_var_is_fix(var_nm,nco_prg_id,nco_pck_plc);  
+
+    if (var_is_fix) var_op_typ=fix_typ;
+
   } /* end if CNV_CCM_CCSM_CF */
 
   /* Warn about any expected weird behavior */
@@ -1310,3 +1252,54 @@ nco_var_lst_dvd_trv                          /* [fnc] Divide input lists into ou
   *prc=var_op_typ;
 
 } /* end nco_var_lst_dvd_trv */
+
+nco_bool
+nco_var_is_fix                               /* [fnc] Variable should be treated as a fixed variable */
+(const char * const var_nm,                  /* I [sng] Variable name */
+ const int nco_prg_id,                       /* I [enm] Program key */
+ const int nco_pck_plc)                      /* I [enm] Packing policy */
+{
+  nco_bool var_is_fix;            /* [fnc] Variable should be treated as a fixed variable (return value) */
+  nco_bool is_sz_rnk_prv_rth_opr; /* [flg] Size- and rank-preserving operator */
+
+  is_sz_rnk_prv_rth_opr=nco_is_sz_rnk_prv_rth_opr(nco_prg_id,nco_pck_plc);
+
+  var_is_fix=False;
+
+  if(!strcmp(var_nm,"ntrm") || !strcmp(var_nm,"ntrn") || !strcmp(var_nm,"ntrk") || !strcmp(var_nm,"ndbase") || !strcmp(var_nm,"nsbase") || !strcmp(var_nm,"nbdate") || !strcmp(var_nm,"nbsec") || !strcmp(var_nm,"mdt") || !strcmp(var_nm,"mhisf")) var_is_fix=True;
+  /* NB: all !strcmp()'s except "msk_" which uses strstr() */
+  if(is_sz_rnk_prv_rth_opr && (!strcmp(var_nm,"hyam") || !strcmp(var_nm,"hybm") || !strcmp(var_nm,"hyai") || !strcmp(var_nm,"hybi") || !strcmp(var_nm,"gw") || !strcmp(var_nm,"lon_bnds") || !strcmp(var_nm,"lat_bnds") || !strcmp(var_nm,"area") || !strcmp(var_nm,"ORO") || !strcmp(var_nm,"date") || !strcmp(var_nm,"datesec") || (strstr(var_nm,"msk_") == var_nm))) var_is_fix=True;
+  /* Known "multi-dimensional coordinates" in CCSM-like model output:
+  lat, lon, lev are normally 1-D coordinates
+  Known exceptions:
+  lat and lon are "2-D coordinates" in NARCCAP output
+  NARCCAP specifies lat and lon in "coordinates" attribute of 2-D fields
+  latixy and longxy are "2-D coordinates" in CLM output
+  CLM does not specify latixy and longxy in "coordinates" attribute of any fields
+  NARCCAP output gives all "coordinate-like" fields an "axis" attribute
+  This includes the record coordinate (i.e., "time") which both ncra and ncwa _should_ process
+  CLM does not give an "axis" attribute to any fields
+  One method of chasing down all "coordinate-like" fields is to look
+  for the field name in the "coordinates" attribute of any variable.
+  However, this will miss (false-negative) the case when no variables 
+  use an N-D coordinate-like variable as a coordinate. 
+  And this may hit (false-positive) the record coordinate (often "time")
+  which should be averaged by ncra, though perhaps not by nces.
+  "coordinate-like" variables that should be "fixed", and not
+  differenced, interpolated, or ensemble-averaged, include those 
+  satisfying these conditions:
+  0. Traditional coordinate (1-D variable same name as its dimension)
+  1. Present in a "coordinates" attribute (except "time" for ncra)
+  2. Present in a "bounds" attribute (except "time_bnds" for ncra)
+  3. Contain an "axis" attribute (except "time") fxm not done yet
+  4. Found in empirical list of variables
+  NB: In the above algorithm discussion, "time" is my shorthand 
+  for "the record variable, if any" */
+
+  /* Conditions #1 and #2 are already implemented above in the case() statement */
+  /* Check condition #4 above: */
+  if(is_sz_rnk_prv_rth_opr && (!strcmp(var_nm,"lat") || !strcmp(var_nm,"lon") || !strcmp(var_nm,"lev") || !strcmp(var_nm,"longxy") || !strcmp(var_nm,"latixy") )) var_is_fix=True;
+
+  return var_is_fix;
+
+} /* nco_var_is_fix() */
