@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/ncrename.c,v 1.191 2014/02/05 23:27:26 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/ncrename.c,v 1.192 2014/03/27 19:19:30 pvicente Exp $ */
 
 /* ncrename -- netCDF renaming operator */
 
@@ -100,8 +100,8 @@ main(int argc,char **argv)
 
   char var_nm[NC_MAX_NAME+1];
 
-  const char * const CVS_Id="$Id: ncrename.c,v 1.191 2014/02/05 23:27:26 pvicente Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.191 $";
+  const char * const CVS_Id="$Id: ncrename.c,v 1.192 2014/03/27 19:19:30 pvicente Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.192 $";
   const char * const opt_sht_lst="a:D:d:g:hl:Oo:p:rv:-:";
   const char dlm_chr='@'; /* Character delimiting variable from attribute name  */
   const char opt_chr='.'; /* Character indicating presence of following variable/dimension/attribute in file is optional */
@@ -336,7 +336,7 @@ main(int argc,char **argv)
   trv_tbl_init(&trv_tbl); 
 
   /* Construct GTT (Group Traversal Table), check -v and -g input names and create extraction list*/
-  (void)nco_bld_trv_tbl(nc_id,trv_pth,(int)0,NULL,(int)0,NULL,False,False,NULL,(int)0,NULL,(int) 0,False,False,False,True,NULL,trv_tbl);
+  (void)nco_bld_trv_tbl(nc_id,trv_pth,(int)0,NULL,(int)0,NULL,False,False,NULL,(int)0,NULL,(int) 0,False,False,False,True,nco_pck_plc_nil,NULL,trv_tbl);
 
   /* Loop input variable names */
   for(int idx_var=0;idx_var<nbr_var_rnm;idx_var++){
